@@ -3,7 +3,7 @@
 
 from herre.auth import get_current_herre
 from arkitekt.threadvars import get_current_assign
-from PyQt5.QtCore import QObject, pyqtSignal
+from qtpy.QtCore import QObject, Signal
 from arkitekt.messages.postman.assign.assign_cancelled import AssignCancelledMessage
 from arkitekt.messages.postman.unassign.bounced_forwarded_unassign import BouncedForwardedUnassignMessage
 from arkitekt.messages.postman.provide.provide_transition import ProvideState, ProvideTransitionMessage
@@ -83,17 +83,17 @@ def qt_to_async(insignal, outsignal, futureMap, function):
 
 
 class QtAgentGeneralWorker(QObject):
-    provideInSignal = pyqtSignal(str, BouncedProvideMessage)
-    provideOutSignal = pyqtSignal(str)
-    provideErrorSignal = pyqtSignal(str, Exception)
+    provideInSignal = Signal(str, BouncedProvideMessage)
+    provideOutSignal = Signal(str)
+    provideErrorSignal = Signal(str, Exception)
 
-    assignInSignal = pyqtSignal(str,tuple, dict)
-    assignOutSignal =  pyqtSignal(str, tuple)
-    assignErrorSignal = pyqtSignal(str, Exception)
+    assignInSignal = Signal(str,tuple, dict)
+    assignOutSignal =  Signal(str, tuple)
+    assignErrorSignal = Signal(str, Exception)
 
-    unprovideInSignal = pyqtSignal(str, BouncedProvideMessage)
-    unprovideOutSignal = pyqtSignal(str)
-    unprovideErrorSignal = pyqtSignal(str, Exception)
+    unprovideInSignal = Signal(str, BouncedProvideMessage)
+    unprovideOutSignal = Signal(str)
+    unprovideErrorSignal = Signal(str, Exception)
 
     def __init__(self, *args,  qt_assign=None, loop= None, qt_on_provide = None, qt_on_unprovide = None, **kwargs) -> None:
         super().__init__(*args, **kwargs)
