@@ -16,6 +16,9 @@ PORTS_FR = """
         ... on SearchWidget {
           query
         }
+        ... on StringWidget {
+          placeholder
+        }
         ... on SliderWidget {
               min
               max  
@@ -28,6 +31,9 @@ PORTS_FR = """
       ... on IntArgPort {
         default
       }
+      ... on EnumArgPort {
+        options
+      }
       ... on ListArgPort {
         child {
           __typename
@@ -59,6 +65,9 @@ PORTS_FR = """
         ... on SearchWidget {
           query
         }
+        ... on StringWidget {
+          placeholder
+        }
         ... on SliderWidget {
           min
           max
@@ -71,6 +80,9 @@ PORTS_FR = """
       ... on IntKwargPort {
         default
       }
+      ... on EnumKwargPort {
+        options
+      }
       ... on ListKwargPort {
         child {
           __typename
