@@ -4,7 +4,7 @@ from arkitekt.messages.postman.reserve.reserve_transition import ReserveState
 from arkitekt.monitor.monitor import Monitor
 from arkitekt.ui.sync_funcs import fill_args_kwargs_graphically
 from arkitekt.schema.enums import NodeType
-from arkitekt.schema.ports import DictArgPort, DictKwargPort, DictReturnPort, IntArgPort, IntKwargPort, IntReturnPort, ListArgPort, ListKwargPort, ListReturnPort, StringArgPort, StringKwargPort, StringReturnPort, StructureArgPort, StructureKwargPort, StructureReturnPort
+from arkitekt.schema.ports import DictArgPort, DictKwargPort, DictReturnPort, EnumArgPort, EnumKwargPort, IntArgPort, IntKwargPort, IntReturnPort, ListArgPort, ListKwargPort, ListReturnPort, StringArgPort, StringKwargPort, StringReturnPort, StructureArgPort, StructureKwargPort, StructureReturnPort
 from arkitekt.graphql.node import NODE_CREATE_QUERY, NODE_GET_QUERY
 from enum import Enum
 from typing import Any, List, Optional, Union
@@ -21,8 +21,8 @@ class Node(GraphQLModel):
     description: Optional[str]
     package: Optional[str]
     interface: Optional[str]
-    args: Optional[List[Union[StructureArgPort, StringArgPort, IntArgPort, ListArgPort, DictArgPort]]]
-    kwargs: Optional[List[Union[StructureKwargPort, StringKwargPort, IntKwargPort, ListKwargPort, DictKwargPort]]]
+    args: Optional[List[Union[StructureArgPort, StringArgPort, IntArgPort, ListArgPort, DictArgPort, EnumArgPort]]]
+    kwargs: Optional[List[Union[StructureKwargPort, StringKwargPort, IntKwargPort, ListKwargPort, DictKwargPort, EnumKwargPort]]]
     returns: Optional[List[Union[StructureReturnPort, StringReturnPort, IntReturnPort, ListReturnPort, DictReturnPort]]]
     type: Optional[NodeType]
 
