@@ -1,4 +1,5 @@
 from abc import abstractmethod
+from enum import Enum
 from arkitekt.schema.widgets import AllWidgets, QueryWidget, SearchWidget, SliderWidget
 from arkitekt.packers.structure import Structure
 from typing import Any, Dict, List, Optional, Union
@@ -55,6 +56,18 @@ class IntExpandShrink:
         return int
 
 
+class EnumExpandShrink:
+
+    async def expand(self, value,**kwargs):
+        return next((key for key, optionvalue in self.options.items() if optionvalue == value), None)
+
+    async def shrink(self, instance,**kwargs):
+       return self.options[instance]
+
+    def to_type(self):
+        return Enum
+
+
 class StringExpandShrink:
 
     async def expand(self, value,**kwargs):
@@ -72,7 +85,7 @@ class StructureExpandShrink:
 
     async def expand(self, value, transpile=True):
         if value is None: return None
-        structure = get_packer_registry().get_structure(self.identifier)
+        structure = get_packer_registry().get_structure(self.get_identifier())
         return await structure.expand(value)
 
     async def shrink(self, instance,**kwargs):
@@ -80,12 +93,12 @@ class StructureExpandShrink:
         if isinstance(instance, Structure) or hasattr(instance, "shrink"): return await instance.shrink()
         # Instance we are trying to shrink needs to be transpile to the required model
         from arkitekt.packers.transpilers.registry import get_transpiler_registry
-        transpiler = get_transpiler_registry().get_transpiler(instance.__class__.__name__, self.identifier)
+        transpiler = get_transpiler_registry().get_transpiler(instance.__class__.__name__, self.get_identifier())
         transpiled_instance = await transpiler.transpile(instance)
         return await transpiled_instance.shrink()
 
     def to_type(self):
-        return get_packer_registry().get_structure(self.identifier)
+        return get_packer_registry().get_structure(self.get_identifier())
     
 
 class ListExpandShrink:
@@ -113,8 +126,9 @@ class DictExpandShrink:
 
 
 # Args
-
-
+class EnumArgPort(ArgPort, EnumExpandShrink):
+    options: Optional[dict]
+    pass
 
 class IntArgPort(ArgPort, IntExpandShrink):
     pass
@@ -152,6 +166,15 @@ class KwargPort(Port):
 class IntKwargPort(KwargPort, IntExpandShrink):
     default: Optional[int]
 
+class EnumKwargPort(KwargPort, EnumExpandShrink):
+    default: Any
+    options: Optional[dict]
+    pass
+
+    @classmethod
+    def from_params(cls, widget=None, default=None, **kwargs):
+        port = cls(__typename=cls.__name__, widget= widget.dict() if widget else None, default=default._value_, **kwargs) # We ensure creation of a proper object)
+        return port
 
 class StringKwargPort(KwargPort, StringExpandShrink):
     default: Optional[str]
