@@ -29,6 +29,10 @@ class SearchWidget(Widget):
 class IntWidget(Widget):
     pass
 
+class StringWidget(Widget):
+    placeholder: Optional[str]
+    pass
+
 class SliderWidget(Widget):
     """ A Slider widget enables
     a slider from min to max with
@@ -44,4 +48,4 @@ class SliderWidget(Widget):
     max: Optional[int]
 
 
-AllWidgets = Union[SearchWidget, IntWidget, SliderWidget, QueryWidget, ValueWidget]
\ No newline at end of file
+AllWidgets = Union[SearchWidget, IntWidget, SliderWidget, QueryWidget, ValueWidget, StringWidget]
\ No newline at end of file
