@@ -1,6 +1,7 @@
 from arkitekt.transport.base import Transport, TransportConfig
 from arkitekt.messages.utils import expandToMessage
 from arkitekt.messages.base import MessageMetaExtensionsModel, MessageModel
+from herre.auth import get_current_herre
 from herre.config.base import BaseConfig
 from enum import Enum
 import websockets
@@ -37,7 +38,7 @@ class WebsocketTransport(Transport):
     def __init__(self, config = None, broadcast=None, **kwargs) -> None:
 
         super().__init__(broadcast)
-        self.config = config or WebsocketTransportConfig.from_file("bergen.yaml", **kwargs)
+        self.config = config or WebsocketTransportConfig.from_file(get_current_herre().config_path, **kwargs)
         self.retries = 5
         self.time_between_retries = 5
         self.connection_alive = False
